@@ -83,20 +83,21 @@ and then communicating via AJAX could be interesting.
 
 =cut
 
-use 5.016;
+use 5.010;
 
 use strict;
 use warnings;
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 use Carp;
 use File::Temp qw(tempfile);
 use Storable qw(dclone);
+use Win32;
 
 my %default_args = (
     H_ADJUST => 44,
-    IE_MODE  => 10,
+    IE_MODE  => 8,
     IP_PORT  => 0,
     W_ADJUST => 24,
     map { $_ => '' } qw/
@@ -278,7 +279,10 @@ sub _handle_sockets {
 =head2 show(%args)
 
 Displays the Application window with mshta.exe. Waits for the application
-to close. For options see L</OPTIONS>.
+to close. Will return the string written by pipe_string() from the
+javascript side of the HTA unless the 'AJAX' option is used.
+
+For options see L</OPTIONS>.
 
 =cut
 sub show {
@@ -300,9 +304,10 @@ sub show {
         or carp "mshta.exe not found in PATH";
 
     if ( $self->ajax() ) {
-        require Win32::Process;
-        require Win32;
-        require JSON;
+        eval { require Win32::Process }
+            or die "Win32::Process is needed for ajax fuctionality\n";
+        eval { require JSON }
+            or die "JSON is needed for ajax fuctionality\n";
 
         Win32::Process::Create(
             my $pobj,
@@ -387,8 +392,8 @@ additional tags place at the beginning of the header (before JS_HEAD)
 
 =head2 IE_MODE
 
-Internet Explorer version that will be emulated by mshta.exe. Defaults to
-10. This could be important especially for javascript capabilities.
+Internet Explorer version that will be emulated by mshta.exe. Defaults to 8.
+This could be important especially for javascript capabilities.
 
 =head2 IP_PORT
 
@@ -463,6 +468,20 @@ callback that has been specified with the AJAX option.
 
 =cut
 
+=head1 AUTHOR
+
+Thomas Kratz E<lt>tomk@cpan.orgE<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2016 by Thomas Kratz
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.8.8 or,
+at your option, any later version of Perl 5 you may have available.
+
+=cut
+
 __DATA__
 <head>
     <meta http-equiv="X-UA-Compatible" content="IE=[%IE_MODE%]" />
@@ -571,8 +590,6 @@ __DATA__
             display: inline-block;
             padding: 0px;
             margin:  0px;
-            #overflow: hidden;
-            #white-space: nowrap;
         }
 
         [%CSS%]
